@@ -1,7 +1,10 @@
-use provola_core::Failure as CoreFailure;
-use provola_core::Report as CoreReport;
-use provola_core::TestCase as CoreTestCase;
-use provola_core::TestSuite as CoreTestSuite;
+use provola_core::report::CoreStatus;
+use provola_core::test::xunit::FullyQualifiedTestCase;
+use provola_core::test::xunit::FullyQualifiedTestCaseId;
+use provola_core::CoreFailure;
+use provola_core::CoreReport;
+use provola_core::CoreTestCase;
+use provola_core::CoreTestSuite;
 use serde::{Deserialize, Serialize};
 
 type Duration = String;
@@ -71,6 +74,8 @@ pub(crate) struct TestInfo {
     failures: Vec<Failure>,
     result: String,
     timestamp: Timestamp,
+    #[serde(skip)]
+    fqtc: Option<FullyQualifiedTestCaseId>,
 }
 
 impl From<UnitTest> for CoreReport {
@@ -90,13 +95,25 @@ impl From<UnitTest> for CoreReport {
 
 impl From<TestCase> for CoreTestSuite {
     fn from(x: TestCase) -> Self {
+        let add_fqtc = |mut test_info: TestInfo| {
+            let fqtc = FullyQualifiedTestCase::from_test_suite_test_case(&x.name, &test_info.name);
+
+            test_info.fqtc = Some(fqtc.id);
+            test_info
+        };
+
         CoreTestSuite {
-            name: x.name,
+            name: x.name.clone(),
             tests: x.tests,
             disabled: Some(x.disabled),
             errors: Some(x.errors),
             failures: Some(x.failures),
-            testcases: x.testsuite.into_iter().map(|x| x.into()).collect(),
+            testcases: x
+                .testsuite
+                .into_iter()
+                .map(add_fqtc)
+                .map(|x| x.into())
+                .collect(),
             time: parse_duration(&x.time),
             timestamp: Some(x.timestamp),
             ..Default::default()
@@ -106,11 +123,23 @@ impl From<TestCase> for CoreTestSuite {
 
 impl From<TestInfo> for CoreTestCase {
     fn from(x: TestInfo) -> Self {
+        let status = match x.status {
+            Status::Run => {
+                if x.failures.is_empty() {
+                    CoreStatus::Pass
+                } else {
+                    CoreStatus::Fail
+                }
+            }
+            Status::NotRun => CoreStatus::Unknown,
+        };
+
         CoreTestCase {
             name: x.name,
-            status: None, // TODO Convert to string, but to which format? Some(x.status),
+            status,
             time: parse_duration(&x.time),
             failures: x.failures.into_iter().map(|x| x.into()).collect(),
+            fqtc: x.fqtc,
             ..Default::default()
         }
     }
